pub(crate) async fn import_public_key(
context: &Context,
public_key: &SignedPublicKey,
) -> Result<()>Expand description
Imports public key into the public key store.
They key may come from Autocrypt header, Autocrypt-Gossip header or a vCard.
If the key with the same fingerprint already exists, it is updated by merging the new key.